| nix_build | R Documentation |
nix-build from an R SessionInvoke Shell Command nix-build from an R Session
nix_build(
project_path = getwd(),
message_type = c("simple", "quiet", "verbose"),
args = NULL
)
project_path |
Path to the folder where the |
message_type |
Character vector with messaging type. Either |
args |
A character vector of additional arguments to be passed directly to
the |
This function is a wrapper for the nix-build command-line interface.
Users can supply any flags supported by nix-build via the args parameter.
If no custom arguments are provided, only the project directory is passed.
Integer of the process ID (PID) of the nix-build shell command
launched, if the nix_build() call is assigned to an R object.
Otherwise, it will be returned invisibly.
Other Nix execution:
with_nix()
## Not run:
# Run nix-build with default arguments (project directory)
nix_build()
# Run nix-build with custom arguments
nix_build(args = c("--max-jobs", "2", "--quiet"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.