tar_nix_ga: Run a Targets Pipeline on GitHub Actions

View source: R/tar_nix_ga.R

tar_nix_gaR Documentation

Run a Targets Pipeline on GitHub Actions

Description

Run a Targets Pipeline on GitHub Actions

Usage

tar_nix_ga()

Details

This function puts a .yaml file inside the ⁠.github/workflows/⁠ folders on the root of your project. This workflow file will use the projects default.nix file to generate the development environment on GitHub Actions and will then run the projects {targets} pipeline. Make sure to give read and write permissions to the GitHub Actions bot.

Value

Nothing, copies file to a directory.

See Also

Other CI/CD: ga_cachix()

Examples

## Not run: 
tar_nix_ga()

## End(Not run)

rix documentation built on Feb. 19, 2026, 1:07 a.m.