| tar_nix_ga | R Documentation |
Run a Targets Pipeline on GitHub Actions
tar_nix_ga()
This function puts a .yaml file inside the .github/workflows/
folders on the root of your project. This workflow file will use the
projects default.nix file to generate the development environment on
GitHub Actions and will then run the projects {targets} pipeline. Make
sure to give read and write permissions to the GitHub Actions bot.
Nothing, copies file to a directory.
Other CI/CD:
ga_cachix()
## Not run:
tar_nix_ga()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.